@@ -2,7 +2,7 @@
 #ifndef _GTKMM_TARGETENTRY_H
 #define _GTKMM_TARGETENTRY_H
 
-/* $Id: targetentry.h 1082 2009-01-19 17:55:19Z murrayc $ */
+/* $Id$ */
 
 /* targetentry.h
  *
@@ -25,7 +25,6 @@
 
 #include <glibmm/utility.h>
 #include <glibmm/ustring.h>
-#include <glibmm/arrayhandle.h>
 #include <gtkmm/enums.h>
 #include <gtk/gtk.h> //For GtkTargetEntry.
 
@@ -69,7 +68,7 @@ protected:
 };
 
 #ifndef DOXYGEN_SHOULD_SKIP_THIS
-struct TargetEntry_Traits
+struct TargetEntryTraits
 {
   typedef TargetEntry CppType;
   typedef GtkTargetEntry CType;
@@ -88,8 +87,6 @@ struct TargetEntry_Traits
 };
 #endif /* DOXYGEN_SHOULD_SKIP_THIS */
 
-typedef Glib::ArrayHandle< TargetEntry, TargetEntry_Traits > ArrayHandle_TargetEntry;
-
 } /* namespace Gtk */
 
 
